@@ -14,7 +14,7 @@ from typing import (
     Union,
 )
 
-import numpy as np
+import numpy as np  # pylint: disable=unused-import
 
 import boost_histogram
 
@@ -31,10 +31,9 @@ def _isstr(value: Any) -> bool:
 
     if isinstance(value, (str, bytes)):
         return True
-    elif hasattr(value, "__iter__"):
+    if hasattr(value, "__iter__"):
         return all(_isstr(v) for v in value)
-    else:
-        return False
+    return False
 
 
 def _opts(**kwargs: bool) -> Set[str]:
@@ -87,7 +86,7 @@ class Axis:
             raise KeyError(
                 "Cannot provide metadata by keyword and __dict__, use __dict__ only"
             )
-        elif __dict__ is not None:
+        if __dict__ is not None:
             self._ax.metadata = __dict__
         elif metadata is not None:
             self._ax.metadata["metadata"] = metadata
@@ -112,21 +111,18 @@ class Axis:
         Return the fractional index(es) given a value (or values) on the axis.
         """
 
-        if not _isstr(value):
-            return self._ax.index(value)  # type: ignore
-        else:
-            raise TypeError(
-                "index({value}) cannot be a string for a numerical axis".format(
-                    value=value
-                )
-            )
+        if _isstr(value):
+            msg = f"index({value}) cannot be a string for a numerical axis"
+            raise TypeError(msg)
+
+        return self._ax.index(value)  # type: ignore[no-any-return]
 
     def value(self, index: float) -> float:
         """
         Return the value(s) given an (fractional) index (or indices).
         """
 
-        return self._ax.value(index)  # type: ignore
+        return self._ax.value(index)  # type: ignore[no-any-return]
 
     def bin(self, index: float) -> Union[int, str, Tuple[float, float]]:
         """
@@ -135,7 +131,7 @@ class Axis:
         non-continuous axis, when given an index.
         """
 
-        return self._ax.bin(index)  # type: ignore
+        return self._ax.bin(index)  # type: ignore[no-any-return]
 
     def __eq__(self, other: Any) -> bool:
         return hasattr(other, "_ax") and self._ax == other._ax
@@ -151,12 +147,12 @@ class Axis:
         return nice_ax
 
     def __len__(self) -> int:
-        return self._ax.size  # type: ignore
+        return self._ax.size  # type: ignore[no-any-return]
 
     def __iter__(
         self,
     ) -> Union[Iterator[float], Iterator[str], Iterator[Tuple[float, float]]]:
-        return self._ax.__iter__()  # type: ignore
+        return self._ax.__iter__()  # type: ignore[no-any-return]
 
     def _process_loc(
         self, start: Optional[AxCallOrInt], stop: Optional[AxCallOrInt]
@@ -221,14 +217,14 @@ class Axis:
         """
         Return number of bins excluding under- and overflow.
         """
-        return self._ax.size  # type: ignore
+        return self._ax.size  # type: ignore[no-any-return]
 
     @property
     def extent(self) -> int:
         """
         Return number of bins including under- and overflow.
         """
-        return self._ax.extent  # type: ignore
+        return self._ax.extent  # type: ignore[no-any-return]
 
     def __getitem__(self, i: AxCallOrInt) -> Union[int, str, Tuple[float, float]]:
         """
@@ -249,21 +245,21 @@ class Axis:
 
     @property
     def edges(self) -> "np.typing.NDArray[Any]":
-        return self._ax.edges  # type: ignore
+        return self._ax.edges  # type: ignore[no-any-return]
 
     @property
     def centers(self) -> "np.typing.NDArray[Any]":
         """
         An array of bin centers.
         """
-        return self._ax.centers  # type: ignore
+        return self._ax.centers  # type: ignore[no-any-return]
 
     @property
     def widths(self) -> "np.typing.NDArray[Any]":
         """
         An array of bin widths.
         """
-        return self._ax.widths  # type: ignore
+        return self._ax.widths  # type: ignore[no-any-return]
 
 
 # Contains all common methods and properties for Regular axes
@@ -486,7 +482,8 @@ class Variable(Axis, family=boost_histogram):
         if len(self) > 20:
             ret = [repr(self.edges)]
         else:
-            ret = ["[{}]".format(", ".join(format(v, "g") for v in self.edges))]
+            args = ", ".join(format(v, "g") for v in self.edges)
+            ret = [f"[{args}]"]
 
         if self.traits.growth:
             ret.append("growth=True")
@@ -669,18 +666,16 @@ class StrCategory(BaseCategory, family=boost_histogram):
         """
 
         if _isstr(value):
-            return self._ax.index(value)  # type: ignore
-        else:
-            raise TypeError(
-                "index({value}) must be a string or iterable of strings for a StrCategory axis".format(
-                    value=value
-                )
-            )
+            return self._ax.index(value)  # type: ignore[no-any-return]
+
+        msg = f"index({value}) must be a string or iterable of strings for a StrCategory axis"
+        raise TypeError(msg)
 
     def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        ret = ["[{}]".format(", ".join(repr(c) for c in self))]
+        args = ", ".join(repr(c) for c in self)
+        ret = [f"[{args}]"]
         ret += super()._repr_args_()
         return ret
 
@@ -732,7 +727,8 @@ class IntCategory(BaseCategory, family=boost_histogram):
     def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        ret = ["[{}]".format(", ".join(format(c, "g") for c in self))]
+        args = ", ".join(format(c, "g") for c in self)
+        ret = [f"[{args}]"]
         ret += super()._repr_args_()
         return ret
 
